from distutils.core import setup
setup(
    name='xkwpy',
    version='1.1.0',
    description='you can use it to change your texts format',
    author='royalxkw',
    url='https://github.com',
    author_email='xkwwangyi@163.com',
)
